Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Command ¶
type Command struct {
Dump DumpCommand `
command:"dump"
description:"dump all messages from a journal file"`
Scan ScanCommand `
command:"scan"
description:"scan and print messages in range"`
Count CountCommand `
command:"count"
description:"count messages in range"`
Offset OffsetCommand `` /* 136-byte string literal not displayed */
Reset ResetCommand `
command:"reset"
description:"reset offset back to a time"`
Tail TailCommand `
command:"tail"
description:"print the tailing messages of a segmented journal directory"`
Old OldCommand `
command:"old"
description:"print old journal files according to rules"`
File FileCommand `
command:"file"
description:"print info about a journal file"`
Timestamp TimestampCommand `
command:"timestamp"
description:"show timestamp of an offset in a journal directory"`
Formatter Formatter
}
Command is the top-level command
type CountCommand ¶
type CountCommand ScanCommand
func (*CountCommand) Execute ¶
func (c *CountCommand) Execute(args []string) error
type DumpCommand ¶
type DumpCommand struct {
JournalFileConfig `positional-args:"yes" required:"yes"`
}
func (*DumpCommand) Execute ¶
func (d *DumpCommand) Execute(args []string) error
type FileCommand ¶
type FileCommand struct {
JournalFileConfig `positional-args:"yes" required:"yes"`
}
func (*FileCommand) Execute ¶
func (c *FileCommand) Execute(args []string) error
type JournalDirConfig ¶
type JournalDirConfig struct {
Dir string
}
type JournalFileConfig ¶
type JournalFileConfig struct {
JournalFile string
}
type OffsetCommand ¶
type OffsetCommand struct {
JournalDirConfig `positional-args:"yes" required:"yes"`
}
func (*OffsetCommand) Execute ¶
func (c *OffsetCommand) Execute(args []string) error
type OldCommand ¶
type OldCommand struct {
Days int `
long:"days"
default:"7"
description:"max number of days of journal files kept after cleanning"`
JournalDirConfig `positional-args:"yes" required:"yes"`
}
func (*OldCommand) Execute ¶
func (c *OldCommand) Execute(args []string) error
type ResetCommand ¶
type ResetCommand struct {
JournalDirConfig `positional-args:"yes" required:"yes"`
Start Timestamp `
long:"start"
description:"start time"`
Offset string `
long:"offset"
description:"the offset"`
Reset bool `
long:"reset"
description:"reset or just print"
`
}
func (*ResetCommand) Execute ¶
func (c *ResetCommand) Execute(args []string) error
type ScanCommand ¶
type ScanCommand struct {
JournalDirConfig `positional-args:"yes" required:"yes"`
Start Timestamp `
long:"start"
description:"start time"`
End Timestamp `
long:"end"
description:"start time"`
Type byte `
long:"type"
description:"message type"`
Format string `
long:"format"
default:"bson"
description:"encoding format of the message"`
Count bool `
long:"count"
description:"count or print"
`
}
func (*ScanCommand) Execute ¶
func (c *ScanCommand) Execute(args []string) error
type TailCommand ¶
type TailCommand struct {
Count int `
long:"count"
description:"the number of tailing messages to print"
default:"10"`
Format string `
long:"format"
default:"bson"
description:"encoding format of the message"`
JournalDirConfig `positional-args:"yes" required:"yes"`
}
func (*TailCommand) Execute ¶
func (c *TailCommand) Execute(args []string) error
type Timestamp ¶
func (*Timestamp) UnmarshalFlag ¶
type TimestampCommand ¶
type TimestampCommand struct {
JournalDirConfig `positional-args:"yes" required:"yes"`
Offset string `
long:"offset"
description:"the offset"`
}
func (*TimestampCommand) Execute ¶
func (d *TimestampCommand) Execute(args []string) error
Click to show internal directories.
Click to hide internal directories.